package com.ygtx.gxt.mapper;

import com.ygtx.gxt.domain.GxtOrderPerson;
import java.util.List;
import java.util.Map;

/**
 * 人员工单工分Mapper接口
 * 
 * @author ruoyi
 */
public interface GxtOrderPersonMapper 
{
    /**
     * 查询人员工单工分列表
     * 
     * @param gxtOrderPerson 人员工单工分
     * @return 人员工单工分集合
     */
    public List<GxtOrderPerson> selectGxtOrderPersonList(GxtOrderPerson gxtOrderPerson);

    public List<GxtOrderPerson> selectGxtScoreDetailList(GxtOrderPerson gxtOrderPerson);

    public int delRepairOrderFlowRecords();

    public int delRepairOrderFlowRecordsNext();

    public int delWorkOrderFlowRecords();

    public int delWorkOrderFlowRecordsNext();

    public int addRepairOrderFlowRecords();

    public int addRepairOrderFlowRecordsNext();

    public int addWorkOrderFlowRecords();

    public int addWorkOrderFlowRecordsNext();

    public Integer repairOrderFlowRecordsSize();

    public Integer workOrderFlowRecordsSize();

    public Integer selectRepairOrderFlowRecordsSize();

    public Integer selectWorkOrderFlowRecordsSize();
}